Module triggers
cardinal_
kernel
0.1.1
Module triggers
Module Items
Functions
In cardinal_
kernel::
engine
cardinal_kernel
::
engine
Module
triggers
Functions

evaluate_
triggers
Evaluate which triggers should fire in response to an event. Returns commands to execute (typically PushStack for triggered effects). This uses card definitions to determine which abilities should fire.